@@ -423,6 +423,9 @@ class PlaceLoader(AddressObjectLoaderBase):
 
     _mapper_class = UIAddressObjectMapper
 
+    def _filter(self, object_data):
+        return bool(object_data['fullName'])
+
 
 class StreetLoader(AddressObjectLoaderBase):
     """
@@ -496,20 +499,23 @@ class UIHouseLoader(HouseLoader):
 
         :rtype: bool
         """
+        filter_string_lower = self.filter_string.lower()
+
         if self.filter_string is None:
             result = True
         else:
             house = (object_data.get('houseNumber') or '').lower()
 
             if house:
-                result = house.startswith(self.filter_string)
+                result = house.startswith(filter_string_lower)
             else:
                 building = (object_data.get('buildingNumber') or '').lower()
                 structure = (object_data.get('structureNumber') or '').lower()
                 result = (
-                    building and building.startswith(self.filter_string) or
-                    structure and structure.startswith(self.filter_string)
+                    (building and building.startswith(filter_string_lower)) or
+                    (structure and structure.startswith(filter_string_lower))
                 )
+
         return result
 
     def _process_object_data(self, drf_object_data):
